@@ -4,11 +4,11 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#include <KHealthCertificate/KHealthCertificate>
-#include <KHealthCertificate/KHealthCertificateParser>
-#include <KHealthCertificate/KRecoveryCertificate>
-#include <KHealthCertificate/KTestCertificate>
-#include <KHealthCertificate/KVaccinationCertificate>
+#include <KHealthCertificate>
+#include <KHealthCertificateParser>
+#include <KRecoveryCertificate>
+#include <KTestCertificate>
+#include <KVaccinationCertificate>
 
 #include <QCoreApplication>
 #include <QQmlEngine>
@@ -32,11 +32,19 @@ public:
 
 QVariant KHealthCertificateParserWrapper::parse(const QVariant &data) const
 {
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     if (data.type() == QVariant::ByteArray) {
-        return KHealthCertificateParser::parse(data.toByteArray());
+#else
+    if (data.userType() == QMetaType::QByteArray) {
+#endif
+      return KHealthCertificateParser::parse(data.toByteArray());
     }
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     if (data.type() == QVariant::String) {
-        return KHealthCertificateParser::parse(data.toString().toUtf8());
+#else
+    if (data.userType() == QMetaType::QString) {
+#endif
+      return KHealthCertificateParser::parse(data.toString().toUtf8());
     }
     return {};
 }
